@@ -35,15 +35,39 @@ def init_entry(fn):
 	entry.set(fn)
 	return entry
 
-def stack_videos(videos,fn):
+def stack_files(files,fmts,fn):
 	'''
 	Stacks .mp4 videos horizontally (and combines audio)
+	the fmts argument is a list of three possible formats: 'a', 'v', or 'av'
+	Videos must match in height.
 	'''
-	nvids=len(videos)
-	instr=''
-	for i in range(len(videos)):
-		instr += ' -i '+videos[i]
-	os.system('ffmpeg -y '+instr+' -filter_complex "[0:v][1:v]hstack=inputs='+str(nvids)+'[v]; [0:a][1:a]amerge[a]" -map "[v]" -map "[a]" -ac 2 '+fn)
+	nv=len([fmt for fmt in fmts if 'v' in fmt])
+	na=len([fmt for fmt in fmts if 'a' in fmt])
+	vf=[i for i,fmt in enumerate(fmts) if 'v' in fmt]
+	af=[i for i,fmt in enumerate(fmts) if 'a' in fmt]
+
+	# 3 cases: 1) Videos and audio, 2) Only videos, 3) Only audio
+	filter_command='"'
+	map_command=''
+	for v in vf:
+		filter_command+='[{}:v]'.format(v)
+	if nv > 0:
+		filter_command+='hstack=inputs={}[v]'.format(nv)
+		if na>0:
+			filter_command+=';'
+		map_command+=' -map "[v]" '
+	for a in af:
+		filter_command+='[{}:a]'.format(a)
+	if na > 0:
+		filter_command+='amerge[a]'
+		map_command+=' -map "[a]" '
+	filter_command+='"'
+	in_command=''
+	for i in range(len(files)):
+		in_command += ' -i '+files[i]
+	full_command = 'ffmpeg -y '+in_command+' -filter_complex '+filter_command+map_command+'-ac 2 '+fn
+	print(full_command)
+	os.system(full_command)
 
 def uiopen(title,filetypes):
 	root=Tk()
@@ -463,7 +487,6 @@ class GUI(ThemedTk):
 		'''
 		if not self.check_data():
 			return
-
 		self.process_H_W()
 		fn_vid=os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mp4'
 		v_shape=self.data['W_shape'][::-1][1:] # Reverse because ffmpeg does hxw
